import { Schema, SchemaLike, ValidationError, ValidationOptions } from 'joi';
import { Handler } from 'express';
import { ExpressOpenAPIPlugin } from './types';
export declare type ResponseSegment = 'body' | 'headers';
declare type JoiResponseSchemaMap = Map<string, {
    [segment in ResponseSegment]?: Schema;
} | undefined>;
declare type JoiResponseValidationSchema = {
    [statusCode: string]: {
        [segment in ResponseSegment]?: SchemaLike;
    };
};
export declare type GetJoiResponseValidatorMiddleware = (joiResponseSchema: JoiResponseValidationSchema, joiValidationOptions?: ValidationOptions) => Handler;
declare type JoiResponseValidatorPlugin = ExpressOpenAPIPlugin<JoiResponseSchemaMap, GetJoiResponseValidatorMiddleware>;
export declare class ResponseValidationError extends Error {
    segment: ResponseSegment;
    validationError: ValidationError;
    constructor(validationError: ValidationError, segment: ResponseSegment);
}
export declare const getJoiResponseValidatorPlugin: ({ skipValidation, segmentOrder, }?: {
    skipValidation?: boolean | undefined;
    segmentOrder?: import("../types").ResponseSegment[] | undefined;
}) => JoiResponseValidatorPlugin;
export {};
