import { AsyncValidationOptions, Schema, SchemaLike, ValidationOptions } from 'joi';
import { Application, Handler } from 'express';
import { OpenAPISpecification } from './openapi';
export declare type RequestSegment = 'body' | 'cookies' | 'headers' | 'params' | 'query' | 'signedCookies';
export declare type ResponseSegment = 'body' | 'headers';
export declare type HttpMethod = 'delete' | 'head' | 'get' | 'options' | 'patch' | 'post' | 'put' | 'trace';
export declare type JoiRequestSchemaMap = Map<RequestSegment, Schema | undefined>;
declare type JoiRequestValidationSchema = {
    [segment in RequestSegment]?: SchemaLike;
};
export declare type GetRequestValidationMiddleware = (joiRequestSchema: JoiRequestValidationSchema, joiValidationOptions?: AsyncValidationOptions, options?: {
    segmentOrder?: RequestSegment[];
}) => Handler;
export declare type JoiResponseSchemaMap = Map<string, {
    [segment in ResponseSegment]?: Schema;
} | undefined>;
declare type JoiResponseValidationSchema = {
    [statusCode: string]: {
        [segment in ResponseSegment]?: SchemaLike;
    };
};
export declare type GetResponseValidationMiddleware = (joiResponseSchema: JoiResponseValidationSchema, joiValidationOptions?: ValidationOptions, options?: {
    segmentOrder?: ResponseSegment[];
}) => Handler;
export declare type PrepareOpenAPISpecification = (app: Application, basePath?: string, specification?: OpenAPISpecification) => OpenAPISpecification;
export {};
